@@ -45,16 +45,23 @@ def pf_active_hardware(ods, pulse):
         if 'OH' in ods[f'pf_active.coil'][c]['name']:
             c_oh += 1
             cname = oh_signals[c_oh]['name']
-            cid = oh_signals[c_oh]['mds_name_resolved'].strip('\\')
+            if oh_signals[c_oh]['mds_name_resolved'] is None:
+                cid = 'None'
+            else:
+                cid = oh_signals[c_oh]['mds_name_resolved'].strip('\\')
         else:
             c_pf += 1
             cname = icoil_signals[c_pf]['name']
-            cid = icoil_signals[c_pf]['mds_name_resolved'].strip('\\')
-        for e in ods[f'pf_active.coil'][c]['element']:
-            if 'OH' in ods[f'pf_active.coil'][c]['name']:
-                ename = oh_signals[c_oh]['mds_name_resolved'].strip('\\') + f'_element_{e}'
+            if icoil_signals[c_pf]['mds_name_resolved'] is None:
+                cid = 'None'
             else:
-                ename = icoil_signals[c_pf]['mds_name_resolved'].strip('\\') + f'_element_{e}'
+                cid = icoil_signals[c_pf]['mds_name_resolved'].strip('\\')
+        for e in ods[f'pf_active.coil'][c]['element']:
+            # if 'OH' in ods[f'pf_active.coil'][c]['name']:
+            #    ename = oh_signals[c_oh]['mds_name_resolved'].strip('\\') + f'_element_{e}'
+            # else:
+            #    ename = icoil_signals[c_pf]['mds_name_resolved'].strip('\\') + f'_element_{e}'
+            ename = cid + f'_element_{e}'
             eid = ename
             ods[f'pf_active.coil'][c]['name'] = cname
             ods[f'pf_active.coil'][c]['identifier'] = cid
@@ -121,7 +128,7 @@ def pf_active_coil_current_data(ods, pulse):
             data = ods[f'pf_active.coil.{channel}.current.data']
             rel_error = data * sig['rel_error']
             abs_error = sig['abs_error']
-            error = np.sqrt(rel_error ** 2 + abs_error ** 2)
+            error = np.sqrt(rel_error**2 + abs_error**2)
             error[np.abs(data) < sig['sig_thresh']] = sig['sig_thresh']
             ods[f'pf_active.coil.{channel}.current.data_error_upper'] = error
 
@@ -201,7 +208,7 @@ def magnetics_floops_data(ods, pulse):
             data = ods[f'magnetics.flux_loop.{channel}.flux.data']
             rel_error = data * tfl_signals[channel + 1]['rel_error']
             abs_error = tfl_signals[channel + 1]['abs_error']
-            error = np.sqrt(rel_error ** 2 + abs_error ** 2)
+            error = np.sqrt(rel_error**2 + abs_error**2)
             error[np.abs(data) < tfl_signals[channel + 1]['sig_thresh']] = tfl_signals[channel + 1]['sig_thresh']
             ods[f'magnetics.flux_loop.{channel}.flux.data_error_upper'] = error
             # 2*pi normalization is done at this stage so that rel_error, abs_error, sig_thresh are consistent with data
@@ -247,7 +254,7 @@ def magnetics_probes_data(ods, pulse):
             data = ods[f'magnetics.b_field_pol_probe.{channel}.field.data']
             rel_error = data * bmc_signals[channel + 1]['rel_error']
             abs_error = bmc_signals[channel + 1]['abs_error']
-            error = np.sqrt(rel_error ** 2 + abs_error ** 2)
+            error = np.sqrt(rel_error**2 + abs_error**2)
             error[np.abs(data) < bmc_signals[channel + 1]['sig_thresh']] = bmc_signals[channel + 1]['sig_thresh']
             ods[f'magnetics.b_field_pol_probe.{channel}.field.data_error_upper'] = error
 
@@ -316,7 +323,7 @@ def ip_bt_dflux_data(ods, pulse):
             data = ods[mappings[item] + '.data']
             rel_error = data * signals[item][0]['rel_error']
             abs_error = signals[item][0]['abs_error'] * signals[item][0]['scale']
-            error = np.sqrt(rel_error ** 2 + abs_error ** 2)
+            error = np.sqrt(rel_error**2 + abs_error**2)
             error[np.abs(data) < signals[item][0]['sig_thresh'] * signals[item][0]['scale']] = (
                 signals[item][0]['sig_thresh'] * signals[item][0]['scale']
             )
@@ -486,6 +493,49 @@ def mse_data(ods, pulse, MSE_revision="ANALYSIS", MSE_Er_correction=True):
         ]
 
 
+# ================================
+@machine_mapping_function(__regression_arguments__, pulse=140001)
+def thomson_scattering_hardware(ods, pulse):
+    """
+    Gathers NSTX(-U) Thomson measurement locations
+
+    :param pulse: int
+
+    """
+    unwrap(thomson_scattering_data)(ods, pulse)
+
+
+@machine_mapping_function(__regression_arguments__, pulse=140001)
+def thomson_scattering_data(ods, pulse):
+    """
+    Loads DIII-D Thomson measurement data
+
+    :param pulse: int
+    """
+
+    signals = ['FIT_NE', 'FIT_NE_ERR', 'FIT_TE', 'FIT_TE_ERR', 'FIT_RADII', 'TS_TIMES']
+    signals_norm = {'FIT_NE': 1.0e6, 'FIT_NE_ERR': 1.0e6, 'FIT_TE': 1e3, 'FIT_TE_ERR': 1e3, 'FIT_RADII': 1e-2, 'TS_TIMES': 1.0}
+
+    TDIs = {}
+    for item in signals:
+        TDI = f'\\ACTIVESPEC::TOP.MPTS.OUTPUT_DATA.BEST.{item}'
+        TDIs[item] = '\\' + TDI.strip('\\')
+    res = mdsvalue('nstxu', pulse=pulse, treename='NSTX', TDI=TDIs).raw()
+    for i, R in enumerate(res['FIT_RADII']):
+
+        ch = ods['thomson_scattering']['channel'][i]
+        ch['name'] = 'ACTIVESPEC::TOP.MPTS.OUTPUT_DATA.BEST' + str(i)
+        ch['identifier'] = 'ACTIVESPEC::TOP.MPTS.OUTPUT_DATA.BEST' + str(i)
+        ch['position']['r'] = R * signals_norm['FIT_RADII']
+        ch['position']['z'] = 0.0
+        ch['n_e.time'] = res['TS_TIMES'] * signals_norm['TS_TIMES']
+        ch['n_e.data'] = res['FIT_NE'][i, :] * signals_norm['FIT_NE']
+        ch['n_e.data_error_upper'] = res['FIT_NE_ERR'][i, :] * signals_norm['FIT_NE_ERR']
+        ch['t_e.time'] = res['TS_TIMES'] * signals_norm['TS_TIMES']
+        ch['t_e.data_error_upper'] = res['FIT_TE_ERR'][i, :] * signals_norm['FIT_TE_ERR']
+        ch['t_e.data'] = res['FIT_TE'][i, :] * signals_norm['FIT_TE']
+
+
 # =====================
 if __name__ == '__main__':
     test_machine_mapping_functions(__all__, globals(), locals())
